/*
 * Copyright (c) 1998-2000 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 *
 * The contents of this file constitute Original Code as defined in and
 * are subject to the Apple Public Source License Version 1.1 (the
 * "License").  You may not use this file except in compliance with the
 * License.  Please obtain a copy of the License at
 * http://www.apple.com/publicsource and read it before using this file.
 *
 * This Original Code and all software distributed under the License are
 * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
 * License for the specific language governing rights and limitations
 * under the License.
 *
 * @APPLE_LICENSE_HEADER_END@
 */
/*
 * Copyright (c) 2000 Apple Computer, Inc.  All rights reserved.
 *
 *  DRI: Josh de Cesare
 *
 */

#include <ctype.h>
#include <stdio.h>
#include <stdlib.h>
#include <limits.h>

#include <CoreFoundation/CoreFoundation.h>
#include <IOKit/IOKitLib.h>

#include "AppleBt8xxCmds.h"

long DoCommands(io_registry_entry_t card);

char        *gAppName;
mach_port_t gMasterPort;


int main(int argc, char **argv)
{
  kern_return_t       ret;
  io_iterator_t       cards;
  io_registry_entry_t card;
  long                done = 0;
  
  
  gAppName = argv[0];
  
  // Get master device port.
  ret = IOMasterPort(bootstrap_port, &gMasterPort);
  if (ret != KERN_SUCCESS) {
    fprintf(stderr, "%s: Failed to get master device port.\n", gAppName);
    exit(-1);
  }
  
  ret = IOServiceGetMatchingServices(gMasterPort,
				     IOServiceNameMatching("AppleBt8xx"),
				     &cards);
  if (ret != KERN_SUCCESS) {
    fprintf(stderr, "%s: Failed to get an iterator for the cards.\n",
	    gAppName);
    exit(-1);
  }
  
  printf("Looking for cards\n");
  while (!done) {
    card = IOIteratorNext(cards);
    if (card == 0) break;
    
    printf("Found card = %x\n", card);
    
    if (DoCommands(card) == 0) done = 1;
    
    IOObjectRelease(card);
  }
  
  IOObjectRelease(cards);
  
  return 0;
}

long DoCommands(io_registry_entry_t card)
{
  char                   str[256];
  UInt32                 reg, data;
  kern_return_t          ret;
  io_connect_t           connect = 0;
  AppleBt8xxCmdSetupInfo info;
  
  ret = IOServiceOpen(card, mach_task_self(), 0, &connect);
  if (ret != kIOReturnSuccess) {
    printf("Failed to make a connection to the card(%x)\n", card);
    return -1;
  }
  
  while (1) {
    fgets(str, 255, stdin);
    str[strlen(str) - 1] = '\0';
    
    if (!strcmp(str, "setup")) {
      ret = AppleBt8xxCmdSetup(connect, &info);
    } else if (!strcmp(str, "start")) {
      ret = AppleBt8xxCmdStart(connect);
    } else if (!strcmp(str, "stop")) {
      ret = AppleBt8xxCmdStop(connect);
    } else if (!strncmp(str, "select ", 7)) {
      sscanf(str+7, "%lx", &data);
      printf("SetSource %lx\n", data);
      ret = AppleBt8xxCmdSetSource(connect, data);
    } else if (!strncmp(str, "tune ", 5)) {
      sscanf(str+5, "%ld", &data);
      printf("Set Tuner Frequency %ld\n", data);
      ret = AppleBt8xxCmdSetTuner(connect, data);
    } else if (!strncmp(str, "rl ", 3)) {
      sscanf(str+3, "%lx", &reg);
      ret = AppleBt8xxCmdReadReg(connect, reg, &data);
      printf("%lx = %lx\n", reg, data);
    } else if (!strncmp(str, "wl ", 3)) {
      sscanf(str+3, "%lx %lx", &reg, &data);
      ret = AppleBt8xxCmdWriteReg(connect, reg, data);
    } else if (!strcmp(str, "uc")) {
      ret = AppleBt8xxCmdNone(connect);
    } else if (!strcmp(str, "quit")) {
      break;
    }
    
    if (ret != kIOReturnSuccess) printf("Error: %x\n", ret);
  }
  
  AppleBt8xxCmdStop(connect);
  
  IOServiceClose(connect);
  
  return 0;
}
