/*
 * Copyright (c) 2000 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 *
 * The contents of this file constitute Original Code as defined in and
 * are subject to the Apple Public Source License Version 1.1 (the
 * "License").  You may not use this file except in compliance with the
 * License.  Please obtain a copy of the License at
 * http://www.apple.com/publicsource and read it before using this file.
 *
 * This Original Code and all software distributed under the License are
 * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
 * License for the specific language governing rights and limitations
 * under the License.
 *
 * @APPLE_LICENSE_HEADER_END@
 *
 * TellyController.h
 * Wilfredo Sanchez | wsanchez@apple.com
 */

#import  <AppKit/AppKit.h>
#include <IOKit/IOKitLib.h>

@interface TellyController : NSObject

{
@private
    /* Driver state */
    BOOL                myPowerBeforeMove; // No accessor
    io_registry_entry_t myVideoCard;
    mach_port_t         myVideoConnect;

    /* Driver configuration */
    NSArray* myInputSourceInfo;

    /* Static configuration */
    NSDictionary* myChannelMap;

@protected
    /* IB outlets */
    IBOutlet NSDrawer*      controlsDrawer;
    IBOutlet NSButton*      tellyView;
    IBOutlet NSWindow*      tellyWindow;
    IBOutlet NSButton*      tellyPowerButton;
    IBOutlet NSPopUpButton* tellyInputSourcePopUp;
    IBOutlet NSPopUpButton* tellyChannelPopUp;
    IBOutlet NSFormCell*    tellyFrequencyFormCell;
    IBOutlet NSFormCell*    tellyChannelFormCell;
    IBOutlet NSSlider*      tellyHueSlider;
    IBOutlet NSSlider*      tellySaturationSlider;
    IBOutlet NSSlider*      tellyContrastSlider;
    IBOutlet NSSlider*      tellyBrightnessSlider;
}

/**
 * Actions
 **/

/**
 * Accessors
 **/

- (BOOL     ) power;
- (int      ) inputSource;
- (float    ) frequency;
- (NSString*) channel;
- (int      ) hue;
- (int      ) saturation;
- (int      ) contrast;
- (int      ) brightness;

- (void) setPower       : (BOOL     ) aValue;
- (void) setInputSource : (int      ) aValue;
- (void) setFrequency   : (float    ) aValue;
- (void) setChannel     : (NSString*) aValue;
- (void) setHue         : (int      ) aValue;
- (void) setSaturation  : (int      ) aValue;
- (void) setContrast    : (int      ) aValue;
- (void) setBrightness  : (int      ) aValue;

/**
 * IB controls
 **/

- (IBAction) frobPower       : (id) aSender;
- (IBAction) frobInputSource : (id) aSender;
- (IBAction) frobChannel     : (id) aSender;
- (IBAction) frobHue         : (id) aSender;
- (IBAction) frobSaturation  : (id) aSender;
- (IBAction) frobContrast    : (id) aSender;
- (IBAction) frobBrightness  : (id) aSender;
- (IBAction) toggleDrawer    : (id) aSender;

@end
